@@ -16,6 +16,7 @@ Git command-line interface for trebuchet
 """
 
 import os
+import imp
 import sys
 import glob
 import argparse
@@ -23,7 +24,9 @@ import argparse
 from trigger import utils
 from trigger import config
 from trigger import extension
-from trigger.driver import FileDriverError, SyncDriverError
+from trigger.driver import LockDriverError
+from trigger.driver import SyncDriverError
+from trigger.driver import ServiceDriverError
 from datetime import datetime
 from git import GitCommandError
 from git.repo import Repo
@@ -46,16 +49,17 @@ class TriggerError(Exception):
 class Trigger(object):
 
     def __init__(self):
-        self._file_driver = CONF.drivers['file-driver']
+        self._lock_driver = CONF.drivers['lock-driver']
         self._sync_driver = CONF.drivers['sync-driver']
+        self._service_driver = CONF.drivers['service-driver']
 
     def do_start(self, args):
-        if self._file_driver.check_lock(args):
+        if self._lock_driver.check_lock(args):
             message = 'A deployment has already been started for this repo.'
             raise TriggerError(message, 100)
         try:
-            self._file_driver.add_lock(args)
-        except FileDriverError as e:
+            self._lock_driver.add_lock(args)
+        except LockDriverError as e:
             LOG.error(e.message)
             raise TriggerError('Failed to start deployment', 101)
         try:
@@ -63,10 +67,10 @@ class Trigger(object):
             # TODO (ryan-lane): Add logging call here
         except TriggerError as e:
             LOG.error(e.message)
-            if self._file_driver.check_lock(args):
+            if self._lock_driver.check_lock(args):
                 try:
-                    self._file_driver.remove_lock(args)
-                except FileDriverError as e:
+                    self._lock_driver.remove_lock(args)
+                except LockDriverError as e:
                     LOG.error(e.message)
             raise TriggerError('Deployment failed to start', 131)
         LOG.info('Deployment started.')
@@ -77,7 +81,7 @@ class Trigger(object):
                default=False,
                help='Do not reset the working tree to the start tag.')
     def do_abort(self, args):
-        if not self._file_driver.check_lock(args):
+        if not self._lock_driver.check_lock(args):
             message = 'There is no deployment to abort.'
             raise TriggerError(message, 130)
         if not args.noreset:
@@ -92,13 +96,13 @@ class Trigger(object):
                 LOG.error('Failed to reset to the start tag.')
                 pass
         try:
-            self._file_driver.remove_lock(args)
-        except FileDriverError as e:
+            self._lock_driver.remove_lock(args)
+        except LockDriverError as e:
             raise TriggerError(e.message, 131)
         LOG.info('Deployment aborted.')
 
     def do_sync(self, args):
-        if not self._file_driver.check_lock():
+        if not self._lock_driver.check_lock(args):
             message = 'A deployment has not been started.'
             raise TriggerError(message, 160)
         if CONF.repo.is_dirty():
@@ -132,8 +136,26 @@ class Trigger(object):
         else:
             return None
 
+    @utils.arg('action',
+               metavar='<action>',
+               help='Service action to take: stop|start|restart|reload')
+    @utils.arg('--batch',
+               dest='batch',
+               help='Number or percentage of targets to target for'
+                    ' batch processing.')
+    def do_service(self, args):
+        """
+        Manage the service associated with this repository.
+        """
+        try:
+            getattr(self.service_driver, args.action)(args)
+        except AttributeError, NotImplementedError:
+            msg = '{0} is not an action implemented by this service driver.'
+            msg = msg.format(args.action)
+            raise TriggerError(msg, 200)
+
     @utils.arg('command', metavar='<subcommand>', nargs='?',
-                    help='Display help for <subcommand>')
+               help='Display help for <subcommand>.')
     def do_help(self, args):
         """
         Display help about this program or one of its subcommands.
